#ifndef __DOXYGEN_H__
#define __DOXYGEN_H__

/** \file
    \brief Doxygen's pages.
*/

/**
\mainpage Welcome to armscope!

\section intro_sec What is armscope

Armscope is a simple low cost digital storage oscilloscope based on AT91SAM7S microcontroller.


\subsection doc_ver_subsec Version

This document corresponds to armscope version 20090921.


\section basic_specification Basic specification:

- single channel,
- 8-bit sampling using internal AT91SAM7S ADC,
- sampling frequency up to 500 kSps,
- uses USB as communication interface,
- USB powered,
- input voltage range from +/-64 mV to +/-16.5 V (ranges graded in 1:3 series), no offset setting,
- triggered by slope or immediately per request,
- capture buffer size from 512 samples to 14336 samples,
- AC or DC coupling
- cost: about $20 assuming you can make PCB on your own and have few hours to spare.


\section details Detailed description

    - \ref hardware
    - \ref firmware
    - \ref pc_software


\section Author
    Tomasz Ostrowski < tomasz dot o dot ostrowski at gmail dot com >

*/


/** \page hardware Hardware

Armscope, VDSO v2 or miniscope v2 is a spin-off from my earlier student project called VDSO.\n
Armscope was assembled and programmed in a few weeks. Since most parts were
pulled out of drawer and it had to be low cost device there are few unusual solutions
used:
- MAX232 works as a voltage booster/inverter, +/-5 V voltages are stabilized by
78L05/79L05,
- CD4066 works as a sensitivity switch and AC/DC coupling switch in preamplifier,
- PCB is 1-sided (remember, LQFP64).

Electric scheme is available at http://tomeko.net/bin/miniscope_v2/miniscope_v2_scheme.pdf .\n
PCB scheme is currently not available - my prototype had problem with noises from USB power
supply. It was partially fixed by placing few additional capacitors on board, but
I would strongly recommend using 2-side PCB with proper layout.

*/


/** \page firmware Firmware

Armscope firmware is simple and straightforward.\n
Main loop scheme:
- check for command from PC,
- execute command if complete command is received,
- check for trigger condition,
- collect samples if triggered (via internal slope trigger or PC \ref CMD_FUNCTION_TRIGGER_EXECUTE request),
- if \ref CMD_FUNCTION_FETCH_DATA was received send full data buffer or special "no data" frame to PC.

\section firmware_compiler Compiler toolset

Toolset used is WinARM version 20070505. Other versions should work too.\n
Go to http://www.siwawi.arubi.uni-kl.de/avr_projects/arm_projects/#winarm

\section firmware_usb_device USB device

Code related to USB device is modified CDC example from Atmel.\n
Main difference is non-blocking read that allows continuous poll for commands
from PC.\n
Atmel USB device/CDC framework does not require user to do any USB polling
(like i.e. Microchip CDC for PIC18Fx5x0 family). This allows to block main
loop for a long time collecting samples from ADC.

\section firmware_upgrade Upgrading firmware

Armscope firmware is upgraded (or loaded in case AT91SAM7S was not programmed before)
via SAM-BA USB bootloader. To allow this make sure BOOT pushbutton is accessible to user.\n
To load firmware unplug device, push BOOT, plug USB, wait about 10 seconds, unplug
device, release boot. After this operation first two FLASH sectors will be overwritten
by bootloader and device will be recognized as "atm 6124.Sys ATMEL AT91xxxxx test Board"
and may ask for compliant driver. Load .bin file with PC SAM-BA application and
replug device.

*/

/** \page pc_software PC software

Armscope is supported by miniscope v3 via suitable dll library.

\image html http://tomeko.net/miniscope_v3/miniscope_v3_0_0_1.png

\section pc_driver Device driver
Although \ref firmware_usb_device implements CDC class armscope uses libusb driver,
not CDC driver from Atmel.

*/
